"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

import argparse
import sys

from fangfrisch import __version__
from fangfrisch.config import LOG_METHOD_CONSOLE
from fangfrisch.config import LOG_METHOD_SYSLOG
from fangfrisch.config.config import config
from fangfrisch.db import DbMeta
from fangfrisch.dump import DumpDbEntries
from fangfrisch.log import LogHandlerType
from fangfrisch.log import eprint
from fangfrisch.log import init_logger
from fangfrisch.refresh import ClamavRefresh


def main() -> int:
    dumpconf = "dumpconf"
    dumpmappings = "dumpmappings"
    initdb = "initdb"
    parser = argparse.ArgumentParser(
        prog="fangfrisch",
        description="Update and verify unofficial ClamAV signatures.",
        epilog=f"Fangfrisch version {__version__}. Copyright © 2020-2025 Ralph Seichter.",
    )
    parser.add_argument("action", choices=[dumpconf, dumpmappings, initdb, "refresh"])
    parser.add_argument("-c", "--conf", default=None, help="configuration file")
    parser.add_argument("-f", "--force", default=False, action="store_true", help="force action (default: False)")
    parser.add_argument("-p", "--provider", default=".", help="provider name filter (regular expression)")
    args = parser.parse_args()
    if not config.init(args.conf):
        eprint(f"Cannot parse configuration file: {args.conf}")
        sys.exit(1)
    format_ = config.log_format()
    level = config.log_level()
    method = config.log_method()
    if method == LOG_METHOD_CONSOLE:
        init_logger(LogHandlerType.CONSOLE, level, format_)
    elif method == LOG_METHOD_SYSLOG:
        init_logger(LogHandlerType.SYSLOG, level, format_, address=config.log_target())
    else:
        eprint(f"Unsupported log method: {method}")
        sys.exit(1)
    if dumpconf == args.action:
        config.write(sys.stdout)
    elif dumpmappings == args.action:
        DumpDbEntries(args).print_url_path_mappings(sys.stdout)
    elif initdb == args.action:
        DbMeta().create_metadata(args.force)
    else:
        DbMeta.assert_version_match()
        ClamavRefresh(args).refresh_all()
    return 0


if __name__ == "__main__":
    sys.exit(main())



"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

CLEANUP = "cleanup"
DB_URL = "db_url"
ENABLED = "enabled"
INTEGRITY_CHECK = "integrity_check"
INTERVAL = "interval"
LOCAL_DIR = "local_directory"
LOG_FORMAT = "log_format"
LOG_LEVEL = "log_level"
LOG_METHOD = "log_method"
LOG_METHOD_CONSOLE = "console"
LOG_METHOD_SYSLOG = "syslog"
LOG_TARGET = "log_target"
MAX_SIZE = "max_size"
ON_UPDATE_EXEC = "on_update_exec"
PREFIX = "prefix"



"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

from fangfrisch.config import INTERVAL
from fangfrisch.config import LOCAL_DIR
from fangfrisch.config import MAX_SIZE
from fangfrisch.config import ON_UPDATE_EXEC
from fangfrisch.config import PREFIX

fangfrischnews = {
    "fangfrischnews": {
        INTERVAL: "12h",
        LOCAL_DIR: "/tmp",
        MAX_SIZE: "100KB",
        "script": "/path/to/fangfrisch-has-news.sh",
        ON_UPDATE_EXEC: f"[ ! -x ${{script}} ] || ${{script}} ${{{LOCAL_DIR}}}",
        PREFIX: r"https://www.seichter.de/fangfrisch/",
        "url_alerts": f"${{{PREFIX}}}fangfrisch_alerts.txt",
        "url_news": f"${{{PREFIX}}}fangfrisch_news.txt",
    }
}



"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

from fangfrisch.config import INTERVAL
from fangfrisch.config import MAX_SIZE
from fangfrisch.config import PREFIX

securiteinfo = {
    "securiteinfo": {
        "customer_id": "you_forgot_to_configure_customer_id",
        INTERVAL: "1h",
        MAX_SIZE: "20MB",
        PREFIX: r"https://www.securiteinfo.com/get/signatures/${customer_id}/",
        "!url_0hour": f"${{{PREFIX}}}securiteinfo0hour.hdb",
        "!url_old": f"${{{PREFIX}}}securiteinfoold.hdb",
        "!url_securiteinfo_mdb": f"${{{PREFIX}}}securiteinfo.mdb",
        "!url_securiteinfo_pdb": f"${{{PREFIX}}}securiteinfo.pdb",
        "!url_securiteinfo_yara": f"${{{PREFIX}}}securiteinfo.yara",
        "url_android": f"${{{PREFIX}}}securiteinfoandroid.hdb",
        "url_ascii": f"${{{PREFIX}}}securiteinfoascii.hdb",
        "url_html": f"${{{PREFIX}}}securiteinfohtml.hdb",
        "url_javascript": f"${{{PREFIX}}}javascript.ndb",
        "url_pdf": f"${{{PREFIX}}}securiteinfopdf.hdb",
        "url_securiteinfo": f"${{{PREFIX}}}securiteinfo.hdb",
        "url_securiteinfo_ign2": f"${{{PREFIX}}}securiteinfo.ign2",
        "url_spam_marketing": f"${{{PREFIX}}}spam_marketing.ndb",
    }
}



"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

from fangfrisch.config import INTEGRITY_CHECK
from fangfrisch.config import INTERVAL
from fangfrisch.config import PREFIX

malwarepatrol = {
    "malwarepatrol": {
        INTERVAL: "1d",
        INTEGRITY_CHECK: "disabled",
        "product": "8",
        "receipt": "you_forgot_to_configure_receipt",
        PREFIX: r"https://lists.malwarepatrol.net/cgi/getfile?product=${product}&receipt=${receipt}&list=",
        "url_clamav_basic": f"${{{PREFIX}}}clamav_basic",
        "filename_clamav_basic": "malwarepatrol.db",
    }
}



"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

from fangfrisch.config import INTERVAL
from fangfrisch.config import PREFIX

sanesecurity = {
    # See https://sanesecurity.com/usage/signatures/
    "sanesecurity": {
        INTERVAL: "1h",
        PREFIX: r"http://mirror.seichter.de/sanesecurity/",
        "!url_foxhole_all_cdb": f"${{{PREFIX}}}foxhole_all.cdb",
        "!url_foxhole_all_ndb": f"${{{PREFIX}}}foxhole_all.ndb",
        "!url_foxhole_links": f"${{{PREFIX}}}foxhole_links.ldb",
        "!url_foxhole_mail": f"${{{PREFIX}}}foxhole_mail.cdb",
        "!url_winnow_phish_complete": f"${{{PREFIX}}}winnow_phish_complete.ndb",
        "url_badmacro": f"${{{PREFIX}}}badmacro.ndb",
        "url_blurl": f"${{{PREFIX}}}blurl.ndb",
        "url_bofhland_cracked_url": f"${{{PREFIX}}}bofhland_cracked_URL.ndb",
        "url_bofhland_malware_attach": f"${{{PREFIX}}}bofhland_malware_attach.hdb",
        "url_bofhland_malware_url": f"${{{PREFIX}}}bofhland_malware_URL.ndb",
        "url_bofhland_phishing_url": f"${{{PREFIX}}}bofhland_phishing_URL.ndb",
        "url_foxhole_filename": f"${{{PREFIX}}}foxhole_filename.cdb",
        "url_foxhole_generic": f"${{{PREFIX}}}foxhole_generic.cdb",
        "url_foxhole_js_cdb": f"${{{PREFIX}}}foxhole_js.cdb",
        "url_foxhole_js_ndb": f"${{{PREFIX}}}foxhole_js.ndb",
        "url_hackingteam": f"${{{PREFIX}}}hackingteam.hsb",
        "url_junk": f"${{{PREFIX}}}junk.ndb",
        "url_jurlbl": f"${{{PREFIX}}}jurlbl.ndb",
        "url_jurlbla": f"${{{PREFIX}}}jurlbla.ndb",
        "url_lott": f"${{{PREFIX}}}lott.ndb",
        "url_malwareexpert_fp": f"${{{PREFIX}}}malware.expert.fp",
        "url_malwareexpert_hdb": f"${{{PREFIX}}}malware.expert.hdb",
        "url_malwareexpert_ldb": f"${{{PREFIX}}}malware.expert.ldb",
        "url_malwareexpert_ndb": f"${{{PREFIX}}}malware.expert.ndb",
        "url_malwarehash": f"${{{PREFIX}}}malwarehash.hsb",
        "url_phish": f"${{{PREFIX}}}phish.ndb",
        "url_phishtank": f"${{{PREFIX}}}phishtank.ndb",
        "url_porcupine": f"${{{PREFIX}}}porcupine.ndb",
        "url_rogue": f"${{{PREFIX}}}rogue.hdb",
        "url_scam": f"${{{PREFIX}}}scam.ndb",
        "url_shelter": f"${{{PREFIX}}}shelter.ldb",
        "url_sigwhitelist": f"${{{PREFIX}}}sigwhitelist.ign2",
        "url_spamattach": f"${{{PREFIX}}}spamattach.hdb",
        "url_spamimg": f"${{{PREFIX}}}spamimg.hdb",
        "url_spear": f"${{{PREFIX}}}spear.ndb",
        "url_spearl": f"${{{PREFIX}}}spearl.ndb",
        "url_ssftm": f"${{{PREFIX}}}sanesecurity.ftm",
        "url_winnow_attachments": f"${{{PREFIX}}}winnow.attachments.hdb",
        "url_winnow_bad_cw": f"${{{PREFIX}}}winnow_bad_cw.hdb",
        "url_winnow_extended_malware": f"${{{PREFIX}}}winnow_extended_malware.hdb",
        "url_winnow_extended_malware_links": f"${{{PREFIX}}}winnow_extended_malware_links.ndb",
        "url_winnow_malware": f"${{{PREFIX}}}winnow_malware.hdb",
        "url_winnow_malware_links": f"${{{PREFIX}}}winnow_malware_links.ndb",
        "url_winnow_phish_complete_url": f"${{{PREFIX}}}winnow_phish_complete_url.ndb",
        "url_winnow_spam_complete": f"${{{PREFIX}}}winnow_spam_complete.ndb",
    }
}



"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

from fangfrisch.config import INTEGRITY_CHECK
from fangfrisch.config import INTERVAL
from fangfrisch.config import MAX_SIZE
from fangfrisch.config import PREFIX

interserver = {
    "interserver": {
        INTERVAL: "1h",
        INTEGRITY_CHECK: "disabled",
        MAX_SIZE: "5MB",
        PREFIX: r"http://sigs.interserver.net/",
        "!url_shell_hdb": f"${{{PREFIX}}}shell.hdb",
        "!url_shellb_db": f"${{{PREFIX}}}shellb.db",
        "url_interserver256": f"${{{PREFIX}}}interserver256.hdb",
        "url_shell_ldb": f"${{{PREFIX}}}shell.ldb",
        "filename_shell_ldb": "interservershell.ldb",
        "url_topline": f"${{{PREFIX}}}interservertopline.db",
        "url_whitelist_fp": f"${{{PREFIX}}}whitelist.fp",
        "filename_whitelist_fp": "interserverwhitelist.fp",
    }
}
